package com.jiuqi.dna.ide.designer.elements;

import com.jiuqi.dna.ide.designer.DesignerBase;
import com.jiuqi.dna.ide.designer.toolkit.PropertyDescriptor;
import com.jiuqi.dna.ide.designer.toolkit.ToolkitElement;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.Iterator;

/* loaded from: com_jiuqi_dna_ide_designer_elements.jar:com/jiuqi/dna/ide/designer/elements/DesignerElement.class */
public abstract class DesignerElement implements IDesignerElement, Serializable {
    protected transient DesignerBase designer;
    protected ToolkitElement toolkitElement;
    protected ICompositeElement parent;
    private String id = "";
    private String text = "";
    private ArrayList<Property> properties = new ArrayList<>();
    private boolean visible = true;
    private boolean initialized = false;

    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public void init() {
        if (isInitialized()) {
            return;
        }
        initProperties();
        fireCreate();
        setInitialized(true);
        this.parent.addChild(this);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public void dispose() {
        if (!isInitialized()) {
            return;
        }
        this.parent.removeChild(this);
        fireDelete();
        setInitialized(false);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public boolean isInitializable() {
        return getToolkitElement() != null && getParent() != null && getParent().isInitialized() && fireVerifyCreate();
    }

    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public boolean isDisposable() {
        return isInitialized() && fireVerifyDelete();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void initProperties() {
        Iterator it = getToolkitElement().getPropertyDescriptors().iterator();
        while (it.hasNext()) {
            PropertyDescriptor descriptor = (PropertyDescriptor) it.next();
            if (getProperty(descriptor.getPropertyName()) == null) {
                addProperty(new Property(descriptor));
            }
            initProperty(descriptor.getPropertyName());
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void initProperty(String propertyName) {
        if ("id".equals(propertyName)) {
            this.id = getPropertyValue("id");
        }
        if ("text".equals(propertyName)) {
            this.text = getPropertyValue("text");
        }
        if ("visible".equals(propertyName)) {
            this.visible = Boolean.getBoolean(getPropertyValue("visible"));
        }
    }

    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public boolean isInitialized() {
        return this.initialized;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void setInitialized(boolean initialized) {
        this.initialized = initialized;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public String getId() {
        return this.id;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public void setId(String id) {
        this.id = id;
        if (hasProperty("id")) {
            setPropertyValue("id", id);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void addProperty(Property property) {
        this.properties.add(property);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public ArrayList<Property> getProperties() {
        return this.properties;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public Property getProperty(String propertyName) {
        if (propertyName == null) {
            return null;
        }
        Iterator<Property> it = this.properties.iterator();
        while (it.hasNext()) {
            Property prop = it.next();
            if (propertyName.equals(prop.getName())) {
                return prop;
            }
        }
        return null;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public String getPropertyValue(String propertyName) {
        Property prop = getProperty(propertyName);
        if (prop != null) {
            return prop.getValue();
        }
        return null;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public boolean hasProperty(String propertyName) {
        return (getToolkitElement() == null || getToolkitElement().getPropertyDescriptor(propertyName) == null) ? false : true;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public void setPropertyValue(String propertyName, String propertyValue) {
        if (!hasProperty(propertyName)) {
            return;
        }
        Property prop = getProperty(propertyName);
        if (prop != null) {
            prop.setValue(propertyValue);
        } else {
            Property prop2 = new Property(propertyName);
            prop2.setValue(propertyValue);
            addProperty(prop2);
        }
        firePropertyChange(propertyName);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public void removeProperty(Property property) {
        this.properties.remove(property);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public void removeProperty(String propertyName) {
        this.properties.remove(getProperty(propertyName));
    }

    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public String getText() {
        return this.text;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public void setText(String text) {
        this.text = text;
        if (hasProperty("text")) {
            setPropertyValue("text", text);
        }
    }

    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public ToolkitElement getToolkitElement() {
        return this.toolkitElement;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public void setToolkitElement(ToolkitElement toolkitElement) {
        this.toolkitElement = toolkitElement;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public boolean isVisible() {
        return this.visible;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public void setVisible(boolean visible) {
        this.visible = visible;
        if (hasProperty("visible")) {
            setPropertyValue("visible", Boolean.toString(visible));
        }
    }

    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public ICompositeElement getParent() {
        return this.parent;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public void setParent(ICompositeElement parent) {
        this.parent = parent;
    }

    /* JADX WARN: Multi-variable type inference failed */
    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public IRootElement getRoot() {
        if (this instanceof IRootElement) {
            return (IRootElement) this;
        }
        if (this.parent == null) {
            return null;
        }
        return this.parent.getRoot();
    }

    @Override // com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public boolean canModifyProperty(String propertyName) {
        return fireVerifyChangeProperty(propertyName);
    }

    public void setDesigner(DesignerBase designer) {
        this.designer = designer;
    }

    public DesignerBase getDesigner() {
        return this.designer;
    }

    protected void firePropertyChange(String propertyName) {
        if (this.designer != null && isInitialized()) {
            this.designer.firePropertyChange(this, propertyName);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void fireCreate() {
        if (this.designer != null) {
            this.designer.fireElementCreate(this);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void fireDelete() {
        if (this.designer != null && isInitialized()) {
            this.designer.fireElementDelete(this);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public boolean fireVerifyCreate() {
        if (this.designer != null) {
            return this.designer.fireVerifyElementCreate(this);
        }
        return false;
    }

    protected boolean fireVerifyDelete() {
        if (this.designer != null && isInitialized()) {
            return this.designer.fireVerifyElementDelete(this);
        }
        return false;
    }

    protected boolean fireVerifyChangeProperty(String propertyName) {
        if (this.designer != null && isInitialized() && hasProperty(propertyName)) {
            return this.designer.fireVerifyElementChangeProperty(this, propertyName);
        }
        return false;
    }
}
